@@ -10,10 +10,11 @@ from leuci_pol import interpolator as pol
 
 #####################################################################
 class MapFunctions(object):
-    def __init__(self, pdb_code, mobj, interp_method):
+    def __init__(self, pdb_code, mobj,pobj, interp_method):
         # PUBLIC INTERFACE
         self.pdb_code = pdb_code        
         self.mobj = mobj
+        self.pobj = pobj
         self.interp = pol.create_interpolator(interp_method,self.mobj.values,self.mobj.F,self.mobj.M,self.mobj.S)
         self.interp_method = interp_method
         
