@@ -53,7 +53,7 @@ class PdbObject(object):
         for atm in self.lines:        
             if atm["chain"] == ch and atm["rid"] == rid and atm["atm"] == am and atm["version"] == ver:        
                 return atm
-        return ""
+        return {}
     
     def get_key(self,atm):
         if atm == {}:
